#!/usr/bin/env python
#
# Copyright (C) 2008  Damien Thebault
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#

from distutils.core import setup, Extension

class PkgConfig:
	def __init__(self, name, version = None):
		self.name = name
		self.version = version
		self.check()
	
	def pkg_version(self):
		""" Format is '<=v', '>=v', '=v' or 'v1<<v2' """
		
		if self.version[0:2] == '<=':
			return ['--max-version=%s' % self.version[2:]]
		elif self.version[0:2] == '>=':
			return ['--atleast-version=%s' % self.version[2:]]
		elif self.version[0] == '=':
			return ['--exact-version=%s' % self.version[1:]]
		else:
			min, max = self.version.split('<<')
			return ['--atleast-version=%s'%min, '--max-version=%s'%max]
	
	def check(self):
		import subprocess, sys
		
		pkgconfig_query = ['pkg-config', self.name] + self.pkg_version()
		pkgconfig = subprocess.Popen(pkgconfig_query)
		
		if pkgconfig == None or pkgconfig.wait() != 0:
			sys.stderr.write('Dependency check failed for ' \
			                 + self.name + ' ' + self.version)
			sys.exit(1)

libasyncns = PkgConfig('libasyncns', '>=0.4')

setup(
	name='libasyncns',
	version='0.7',
	author='Damien Thebault',
	author_email='damien.thebault@gmail.com',
	url='https://launchpad.net/libasyncns-python',
	description='python binding for libasyncns',
	license='LGPL 2.1',
	long_description='libasyncns-python is a python binding for the libasyncns asynchronous name service query library',
	ext_modules=[
		Extension('libasyncns',
			['addrinfoquery.c',
			 'asyncns.c',
			 'libasyncns.c',
			 'nameinfoquery.c',
			 'query.c',
			 'resquery.c'],
			libraries=['asyncns'],
			extra_compile_args=['-Wall', '-Wextra', '-Wno-unused']),
	],
)

